@@ -142,6 +142,21 @@ legend.grob <- function(
 				legendi[['width']]  <- if (is.null(legendi[['width']])) { 2 } else { legendi[['width']] };
 
 				colorRamp <- colorRampPalette(legendi[['colours']]);
+		
+                labels.at <- legendi[['at']];
+                if (!is.null(legendi[['labels']]) && (is.null(labels.at))) {
+                    n.labels <- length(legendi[['labels']]);
+        
+                    # Uses 0-100% as a default range
+                    max.value <- if (!is.null(legendi[['continuous.amount']])) legendi[['continuous.amount']] else 100;
+                    boundaries <- seq(0, max.value, length.out = n.labels + 1);
+
+                    labels.at <- sapply(
+                        1:(length(boundaries) - 1),
+                        FUN = function(i) boundaries[i] + (boundaries[i + 1] - boundaries[i]) / 2
+                        );
+                    }
+
 				legend.key <- list(
 					space = if (!is.null(legendi[['angle']]) && legendi[['angle']] != 0) { 'bottom' } else { 'right' },
 					between = 0.5,
@@ -154,7 +169,7 @@ legend.grob <- function(
 					width = if (!is.null(legendi[['angle']]) && legendi[['angle']] != 0) { legendi[['height']] } else { legendi[['width']] },
 					labels = list(
 						labels = if (is.null(legendi[['labels']])) { c('') } else { legendi[['labels']] },
-						at     = if (is.null(legendi[['at']])) { NULL } else { legendi[['at']] },
+						at     = labels.at,
 						cex    = if (is.null(legendi[['cex']])) { 0.8 } else { legendi[['cex']] },
 						rot    = if (is.null(legendi[['labels.rot']])) { 0 } else { legendi[['labels.rot']] }
 						)
